==> redland_0.9.19.orig.tar.gz: redland-0.9.19/rasqal/sparql_parser.h <==
/* A Bison parser, made by GNU Bison 1.875c.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SELECT = 258,
     SOURCE = 259,
     FROM = 260,
     WHERE = 261,
     AND = 262,
     OPTIONAL = 263,
     PREFIX = 264,
     DESCRIBE = 265,
     CONSTRUCT = 266,
     ASK = 267,
     NOT = 268,
     DISTINCT = 269,
     LIMIT = 270,
     COMMA = 271,
     LPAREN = 272,
     RPAREN = 273,
     LSQUARE = 274,
     RSQUARE = 275,
     VARPREFIX = 276,
     AMP = 277,
     SC_AND = 278,
     SC_OR = 279,
     STR_NMATCH = 280,
     STR_MATCH = 281,
     STR_NE = 282,
     STR_EQ = 283,
     GE = 284,
     LE = 285,
     GT = 286,
     LT = 287,
     NEQ = 288,
     EQ = 289,
     REM = 290,
     SLASH = 291,
     STAR = 292,
     MINUS = 293,
     PLUS = 294,
     BANG = 295,
     TILDE = 296,
     FLOATING_POINT_LITERAL = 297,
     STRING_LITERAL = 298,
     PATTERN_LITERAL = 299,
     INTEGER_LITERAL = 300,
     BOOLEAN_LITERAL = 301,
     NULL_LITERAL = 302,
     URI_LITERAL = 303,
     QNAME_LITERAL = 304,
     IDENTIFIER = 305,
     ERROR_TOKEN = 306
   };
#endif
#define SELECT 258
#define SOURCE 259
#define FROM 260
#define WHERE 261
#define AND 262
#define OPTIONAL 263
#define PREFIX 264
#define DESCRIBE 265
#define CONSTRUCT 266
#define ASK 267
#define NOT 268
#define DISTINCT 269
#define LIMIT 270
#define COMMA 271
#define LPAREN 272
#define RPAREN 273
#define LSQUARE 274
#define RSQUARE 275
#define VARPREFIX 276
#define AMP 277
#define SC_AND 278
#define SC_OR 279
#define STR_NMATCH 280
#define STR_MATCH 281
#define STR_NE 282
#define STR_EQ 283
#define GE 284
#define LE 285
#define GT 286
#define LT 287
#define NEQ 288
#define EQ 289
#define REM 290
#define SLASH 291
#define STAR 292
#define MINUS 293
#define PLUS 294
#define BANG 295
#define TILDE 296
#define FLOATING_POINT_LITERAL 297
#define STRING_LITERAL 298
#define PATTERN_LITERAL 299
#define INTEGER_LITERAL 300
#define BOOLEAN_LITERAL 301
#define NULL_LITERAL 302
#define URI_LITERAL 303
#define QNAME_LITERAL 304
#define IDENTIFIER 305
#define ERROR_TOKEN 306




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 104 "./sparql_parser.y"
typedef union YYSTYPE {
  raptor_sequence *seq;
  rasqal_variable *variable;
  rasqal_literal *literal;
  rasqal_triple *triple;
  rasqal_expression *expr;
  double floating;
  raptor_uri *uri;
  unsigned char *name;
} YYSTYPE;
/* Line 1275 of yacc.c.  */
#line 150 "sparql_parser.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

==> redland-1.0.0.tar.gz: redland-1.0.0/rasqal/sparql_parser.h <==
/* A Bison parser, made by GNU Bison 1.875c.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     SELECT = 258,
     SOURCE = 259,
     FROM = 260,
     WHERE = 261,
     AND = 262,
     OPTIONAL = 263,
     PREFIX = 264,
     DESCRIBE = 265,
     CONSTRUCT = 266,
     ASK = 267,
     NOT = 268,
     DISTINCT = 269,
     LIMIT = 270,
     UNION = 271,
     BASE = 272,
     LOAD = 273,
     BOUND = 274,
     STR = 275,
     LANG = 276,
     DATATYPE = 277,
     ISURI = 278,
     ISBLANK = 279,
     ISLITERAL = 280,
     SC_AND = 281,
     SC_OR = 282,
     STR_NMATCH = 283,
     STR_MATCH = 284,
     STR_NE = 285,
     STR_EQ = 286,
     GE = 287,
     LE = 288,
     GT = 289,
     LT = 290,
     NEQ = 291,
     EQ = 292,
     FLOATING_POINT_LITERAL = 293,
     STRING_LITERAL = 294,
     PATTERN_LITERAL = 295,
     INTEGER_LITERAL = 296,
     BOOLEAN_LITERAL = 297,
     NULL_LITERAL = 298,
     URI_LITERAL = 299,
     QNAME_LITERAL = 300,
     BLANK_LITERAL = 301,
     IDENTIFIER = 302
   };
#endif
#define SELECT 258
#define SOURCE 259
#define FROM 260
#define WHERE 261
#define AND 262
#define OPTIONAL 263
#define PREFIX 264
#define DESCRIBE 265
#define CONSTRUCT 266
#define ASK 267
#define NOT 268
#define DISTINCT 269
#define LIMIT 270
#define UNION 271
#define BASE 272
#define LOAD 273
#define BOUND 274
#define STR 275
#define LANG 276
#define DATATYPE 277
#define ISURI 278
#define ISBLANK 279
#define ISLITERAL 280
#define SC_AND 281
#define SC_OR 282
#define STR_NMATCH 283
#define STR_MATCH 284
#define STR_NE 285
#define STR_EQ 286
#define GE 287
#define LE 288
#define GT 289
#define LT 290
#define NEQ 291
#define EQ 292
#define FLOATING_POINT_LITERAL 293
#define STRING_LITERAL 294
#define PATTERN_LITERAL 295
#define INTEGER_LITERAL 296
#define BOOLEAN_LITERAL 297
#define NULL_LITERAL 298
#define URI_LITERAL 299
#define QNAME_LITERAL 300
#define BLANK_LITERAL 301
#define IDENTIFIER 302




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 107 "./sparql_parser.y"
typedef union YYSTYPE {
  raptor_sequence *seq;
  rasqal_variable *variable;
  rasqal_literal *literal;
  rasqal_triple *triple;
  rasqal_expression *expr;
  rasqal_graph_pattern *graph_pattern;
  double floating;
  raptor_uri *uri;
  unsigned char *name;
} YYSTYPE;
/* Line 1275 of yacc.c.  */
#line 143 "sparql_parser.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
